pack-objects: mark add_to_write_order() as inline
This function is a whole 26 bytes when compiled on x86_64, but is currently invoked over 1.037 billion times when running pack-objects on the Linux kernel git repository. This is hitting the point where micro-optimizations do make a difference, and inlining it only increases the object file size by 38 bytes. As reported by perf, this dropped task-clock from 84183 to 83373 ms, and total cycles from 223.5 billion to 221.6 billion. Not astronomical, but worth getting for adding one word. Signed-off-by: Dan McGee <dpmcgee@gmail.com> Signed-off-by: Junio C Hamano <gitster@pobox.com>
Dan McGee committed
Oct 18, 2011 at 00:21 UTC
be12681896fab9455eb65ea124df423b462e0072
1 file changed
+1
-1
builtin/pack-objects.c
+1
-1
@@ -454,7 +454,7 @@ static int mark_tagged(const char *path, const unsigned char *sha1, int flag,
454
return 0;
455
}
456
457
-static void add_to_write_order(struct object_entry **wo,
457
+static inline void add_to_write_order(struct object_entry **wo,
458
int *endp,
459
struct object_entry *e)
460
{